from setuptools import setup

setup(name='distributions_me',
      version='0.1',
      description='Gaussian distributions',
      author='Maria',
      packages=['distributions_me'],
      zip_safe=False)
